Module: Himari::RackOAuth2Ext::ErrorIssuerParam

Defined in:
lib/himari/rack_oauth2_ext.rb

Overview

Carried by error responses, but only emitted when the error is actually delivered to the client via redirect. RFC 9207 covers authorization responses, not the JSON error bodies rack-oauth2 returns directly to the user agent when there is no trusted redirect_uri.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#issObject

Returns the value of attribute iss.



30
31
32
# File 'lib/himari/rack_oauth2_ext.rb', line 30

def iss
  @iss
end

Instance Method Details

#protocol_paramsObject



32
33
34
# File 'lib/himari/rack_oauth2_ext.rb', line 32

def protocol_params
  redirect? ? super.merge(iss:) : super
end